# -*- coding: utf-8 -*-
from setuphelpers import *

"""
{
   "key":"{42658E02-4559-4B38-9F25-E1F67B75FEE3}",
   "name":"Seafile 9.0.5",
   "version":"9.0.5",
   "install_date":"2024-03-18 00:00:00",
   "install_location":"",
   "uninstall_string":"MsiExec.exe /X{42658E02-4559-4B38-9F25-E1F67B75FEE3}",
   "publisher":"HaiWenHuZhi ltd.",
   "system_component":0,
   "win64":true
  }
"""


def install():
    bin_name = glob.glob("seafile-*.msi")[0]
    install_msi_if_needed(
        bin_name,
        min_version=control.get_software_version(),
        timeout=600,
    )

    # Clear the uninstallkeys to avoid the no-code audit and uninstall
    uninstallkey.clear()


def session_setup():
    print("Disabling: auto-update check and configuring base options")
    registry_setstring(HKEY_CURRENT_USER, r"Software\Seafile", "ShellExtDisabled", "1")
    registry_setstring(HKEY_CURRENT_USER, r"Software\Seafile\Seafile Client\Language", "current", "en")
    registry_setstring(HKEY_CURRENT_USER, r"Software\Seafile\Seafile Client\Misc", "SparkleAlreadyEnableUpdateByDefault", "true")
    registry_setstring(HKEY_CURRENT_USER, r"Software\Seafile\Seafile Client\WinSparkle", "CheckForUpdates", "0")
    registry_setstring(HKEY_CURRENT_USER, r"Software\Seafile\Seafile Client\Behavior", "hideMainWindowWhenStarted", "true")


def audit():
    # Declaring local variables
    audit_status = "OK"
    app_check = installed_softwares("Seafile")
    if app_check:
        installed_version = app_check[0]["version"]
        control.name = app_check[0]["name"]
    else:
        installed_version = ""
        control.name = control.package.split("-", 1)[-1].replace("-", " ").title()
    audit_version = False

    # Auditing software
    if not installed_version:
        print(f"{control.name} is not installed.")
        audit_status = "ERROR"
    elif audit_version and Version(installed_version, 4) < Version(control.get_software_version(), 4):
        print(f"{control.name} ({installed_version}) installed version should be: {control.get_software_version()}")
        audit_status = "WARNING"
    else:
        print(f"{control.name} is installed." if installed_version in control.name else f"{control.name} ({installed_version})  is installed.")
        audit_status = "OK"

    return audit_status


def uninstall():
    # "C:\Program Files\Seafile\bin\seafile-applet.exe" --remove-user-data
    try:
        for app_check in installed_softwares("Seafile"):
            run(uninstall_cmd(app_check["key"]), timeout=60)
    except:
        killalltasks("seafile-applet.exe")
        killalltasks(ensure_list(control.impacted_process))
        wait_uninstallkey_absent(keywords="Seafile")
        time.sleep(60)
        if installed_softwares("Seafile"):
            error("Uninstalling Seafile was unsuccessful.")
